==> nextcloud-31.0.9.tgz: nextcloud/apps/password_policy/l10n/et_EE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Salasõna on aegunud, palun kasuta lähtestamiseks unustatud salasõna meetodit",
    "Password must not have been used recently before." : "Salasõna ei tohi olla hiljuti kasutatud.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Salasõna kuulub 1000000 kõige tavalisema hulka. Palun tee see ainulaadseks.",
    "Password is present in compromised password list. Please choose a different password." : "Salasõna leidub rääderdatud ehk lekkinud salasõnade nimekirjas. Palun vali teistsugune salasõna.",
    "Password needs to be at least %s characters long." : "Salasõna peab olema vähemalt %s sümbolit pikk.",
    "Password needs to contain at least one numeric character." : "Salasõna peab sisaldama vähemalt üht numbrit.",
    "Password needs to contain at least one special character." : "Salasõna peab sisaldama vähemalt üht erimärki.",
    "Password needs to contain at least one lower and one upper case character." : "Salasõna peab sisaldama vähemalt üht väike- ja üht suurtähte.",
    "Password policy" : "Salasõnade reeglid",
    "Allows admins to configure a password policy" : "Lubab peakasutajatel seadistada salasõnade reegleid",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Luba peakasutajatel määrata teatud eelnõuded salasõnadele, nt. kehtestada miinimumpikkus.",
    "General password policies" : "Üldised reeglid salasõnadele",
    "Add policy set" : "Lisa reegel",
    "Login policies" : "Sisselogimise reeglid",
    "Password history size" : "Salasõnade ajaloo pikkus",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Salasõnade arv, mida säilitada (turvaliselt räsitud), et kasutajad ei saaks varemkasutatud salasõnu uuesti kasutada.",
    "Maximum login attempts" : "Maksimaalne arv sisselogimiskatseid",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Sisselogimiskatsete arv enne kasutajakonto keelamist kuni käsitsi toimingute vajaduseni. (0 piiranguteta)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Pane tähele, et see valik on mõeldud rünnatud kontode kaitsmiseks. Keelatud kontod peab administraator käsitsi uuesti lubama. Kui ründaja üritab ära arvata kasutajakontode salasõnu, siis tema IP-aadress saab olema blokeeritud jõuründe kaitsega, sõltumata sellest seadistusest.",
    "Number of days until user password expires" : "Päevade arv salasõna aegumiseni",
    "Password expiration" : "Salasõna aegumine",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Hoiatus: salasõna aegumise lubamist peavad tänapäeval mitmed turvaasutused turvariskiks.",
    "Remove policy" : "Eemalda reegel",
    "Minimum password length" : "Salasõna minimaalne pikkus",
    "Forbid common passwords" : "Keela laialtlevinud salasõnad",
    "Enforce upper and lower case characters" : "Eelda suur- ja väiketähede kasutamist",
    "Enforce numeric characters" : "Eelda numbrite kasutamist",
    "Enforce special characters" : "Eelda erimärkide kasutamist",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrolli salasõna haveibeenpwned.com lekkinud salasõnade loendist",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "See kontroll arvutab salasõna räsi, saadab selle 5 esimest sümbolit haveibeenpwned.com API-le ja saab vastu nimekirja sama algusega räsidest. Seejärel kontrollitakse Nextcloudi serveris, kas salasõna räsi on tulemuste hulgas.",
    "Account password policies" : "Kasutajakonto reeglid salasõnadele",
    "Share password policies" : "Jaga reegleid salasõnadele",
    "Unknown error" : "Tundmatu viga",
    "Minimal length has to be a non negative number" : "Miinimumpikkus peab olema positiivne arv",
    "History size has to be a non negative number" : "Ajaloo pikkus peab olema positiivne arv",
    "Expiration days have to be a non negative number" : "Aegumise kestus peab olema positiivne arv",
    "Maximum login attempts have to be a non negative number" : "Sisselogimiskatsete arv peab olema positiivne arv",
    "Settings saved" : "Seadistused on salvestatud",
    "Error while saving settings" : "Viga seadistuste salvestamisel",
    "User password history" : "Kasutaja salasõna ajalugu"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.3.tgz: nextcloud/apps/password_policy/l10n/et_EE.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Salasõna on aegunud, palun kasuta lähtestamiseks unustatud salasõna meetodit",
    "Password must not have been used recently before." : "Salasõna ei tohi olla hiljuti kasutatud.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Salasõna kuulub 1000000 kõige tavalisema hulka. Palun tee see ainulaadseks.",
    "Password is present in compromised password list. Please choose a different password." : "Salasõna leidub rääderdatud ehk lekkinud salasõnade nimekirjas. Palun vali teistsugune salasõna.",
    "Password needs to be at least %s characters long." : "Salasõna peab olema vähemalt %s sümbolit pikk.",
    "Password needs to contain at least one numeric character." : "Salasõna peab sisaldama vähemalt üht numbrit.",
    "Password needs to contain at least one special character." : "Salasõna peab sisaldama vähemalt üht erimärki.",
    "Password needs to contain at least one lower and one upper case character." : "Salasõna peab sisaldama vähemalt üht väike- ja üht suurtähte.",
    "Password policy" : "Salasõnade reeglid",
    "Allows admins to configure a password policy" : "Lubab peakasutajatel seadistada salasõnade reegleid",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Luba peakasutajatel määrata teatud eelnõuded salasõnadele, nt. kehtestada miinimumpikkus.",
    "General password policies" : "Üldised salasõnade reeglid",
    "Add policy set" : "Lisa reegel",
    "Login policies" : "Sisselogimise reeglid",
    "Password history size" : "Salasõnade ajaloo pikkus",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Salasõnade arv, mida säilitada (turvaliselt räsitud), et kasutajad ei saaks varemkasutatud salasõnu uuesti kasutada.",
    "Maximum login attempts" : "Maksimaalne arv sisselogimiskatseid",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Sisselogimiskatsete arv enne kasutajakonto keelamist kuni käsitsi toimingute vajaduseni. (0 piiranguteta)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Pane tähele, et see valik on mõeldud rünnatud kontode kaitsmiseks. Keelatud kontod peab administraator käsitsi uuesti lubama. Kui ründaja üritab ära arvata kasutajakontode salasõnu, siis tema IP-aadress saab olema blokeeritud jõuründe kaitsega, sõltumata sellest seadistusest.",
    "Number of days until user password expires" : "Päevade arv salasõna aegumiseni",
    "Password expiration" : "Salasõna aegumine",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Hoiatus: salasõna aegumise lubamist peavad tänapäeval mitmed turvaasutused turvariskiks.",
    "Remove policy" : "Eemalda reegel",
    "Minimum password length" : "Salasõna minimaalne pikkus",
    "Forbid common passwords" : "Keela laialtlevinud salasõnad",
    "Enforce upper and lower case characters" : "Eelda suur- ja väiketähede kasutamist",
    "Enforce numeric characters" : "Eelda numbrite kasutamist",
    "Enforce special characters" : "Eelda erimärkide kasutamist",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Kontrolli salasõna haveibeenpwned.com lekkinud salasõnade loendist",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "See kontroll arvutab salasõna räsi, saadab selle 5 esimest sümbolit haveibeenpwned.com API-le ja saab vastu nimekirja sama algusega räsidest. Seejärel kontrollitakse Nextcloudi serveris, kas salasõna räsi on tulemuste hulgas.",
    "Account password policies" : "Kasutajakonto reeglid salasõnadele",
    "Share password policies" : "Jaga reegleid salasõnadele"
},
"nplurals=2; plural=(n != 1);");
